@@ -47,4 +47,13 @@ download_fcp_file = function(
   download_hcp_file(...,
                     bucket = "fcp-indi",
                     sign = FALSE)
+}
+
+#' @export
+#' @rdname download_hcp_file
+download_openneuro_file = function(
+  ...) {
+  download_hcp_file(...,
+                    bucket = "openneuro",
+                    sign = FALSE)
 }
\ No newline at end of file
