@@ -11,11 +11,16 @@
 #' @examples
 #' if (have_aws_key()){
 #'    ret = hcp_list_files(prefix = "HCP/100307/unprocessed/3T/Diffusion")
-#'         parsed = parse_list_files(ret)
+#'    parsed = parse_list_files(ret)
+#'    stopifnot(!is.null(parsed$contents))
 #'  }
 parse_list_files = function(ret) {
   res = ret$parsed_result
   nres = names(res)
+  if ("ListBucketResult" %in% nres) {
+    res = res$ListBucketResult
+    nres = names(res)
+  }
 
   xml_to_df = function(x) {
     df = t(sapply(x, unlist))
